@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Copyright 2012 Major Hayden
+# Copyright 2014 Major Hayden
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -194,6 +194,6 @@ def run_supernova_keyring():
         else:
             print "\n[%s] Unable to retrieve credentials for %s.\nThere are " \
                   "probably no credentials stored for this environment/" \
-                  "parameter combination (try --set)." % (
-                  rwrap("Failed"), username)
+                  "parameter combination (try --set)." % (rwrap("Failed"),
+                                                          username)
             sys.exit(1)
